


(****************  Parameters *************)

M$ParametersHiggsBasis = {

(*  MH == {                                      *)
(*        TeX -> Subscript[M, H],                *)
(*         ParameterType -> External,            *)
(*         Value -> 125.,                        *)
(*        Description -> "H mass: MH < MS"},     *)

(*   MS == {                                     *)
(*         TeX -> Subscript[M, S],               *)
(*         ParameterType -> External,            *)
(*         Value -> 250.,                        *)
(*         Description -> "S mass: MH < MS"},    *)

(* Mixing angle *)
    sinalf == {
        TeX -> Subscript[s, \[Alpha] ],
        ParameterType    -> External,
        ComplexParameter -> False,
        Value            -> 0.3,
        ParameterName    -> sinalf,
        Description      -> "sine of the scalar mixing angle" },

      cosalf == {
        TeX -> Subscript[c, \[Alpha] ],
        ParameterType    -> Internal,
        ComplexParameter -> False,
        Value            -> Sqrt[1-sinalf^2],
        ParameterName    -> cosalf,
        Description      -> "cosine of the scalar mixing angle"},

(*Higgs selfcouplings *)

   mu1 == {
        ParameterType -> Internal,
        ComplexParameter -> False,
        Value         -> vev^2 l1 + sev^2 l3/2,
        Definitions   -> { mu1 -> vev^2 l1 + sev^2 l3/2},
        TeX           -> Subscript[\[Mu], H],
        ParameterName -> mu1,
        Description   -> "Coefficient of the quadratic piece of the Higgs potential"},

   mu2 == {
        ParameterType -> Internal,
        ComplexParameter -> False,
        Value         -> sev^2 l2 + vev^2 l3/2,
        Definitions   -> { mu2 -> sev^2 l2 + vev^2 l3/2},
        TeX           -> Subscript[\[Mu], S],
        ParameterName -> mu2,
        Description   -> "Coefficient of the quadratic piece of the Singlet potential"},

  l1 == {
        ParameterType -> Internal,
        ComplexParameter -> False,
        TeX -> Subscript[\[Lambda], 1],
        InteractionOrder -> {QED,2},
        Value            -> (MH^2 cosalf^2 + MS^2 sinalf^2)/2/vev^2,
        Definitions      -> { l1 -> (MH^2 cosalf^2 + MS^2 sinalf^2)/2/vev^2 },
        ParameterName -> l1,
        Description      -> "Higgs quartic coupling"},

  l2 == {
        ParameterType -> Internal,
        ComplexParameter -> False,
        TeX -> Subscript[\[Lambda], 2],
        Value            -> (MH^2 sinalf^2 + MS^2 cosalf^2)/2/sev^2,
        Definitions      -> { l2 -> (MH^2 sinalf^2 + MS^2 cosalf^2)/2/sev^2 },
        InteractionOrder -> {QED,2},
        ParameterName -> l2,
        Description      -> "Singlet quartic coupling"},

 l3 == {
        ParameterType -> Internal,
        ComplexParameter -> False,
        TeX -> Subscript[\[Lambda], 3],
        Value            -> (MS^2 - MH^2) sinalf cosalf/sev/vev,
        Definitions      -> { l3 -> (MS^2 - MH^2) sinalf cosalf/sev/vev },
        InteractionOrder -> {QED,2},
        ParameterName -> l3,
        Description      -> "Higgs-Singlet quartic coupling"},

tgb == {
        ParameterType    -> External,
        ComplexParameter -> False,
        TeX -> tg\[Beta],
        Value            -> 3.0,
        ParameterName    -> tgb,
        Description      -> "tgb = vev/sev" }

};


(* *********************************** *)
(*                                     *)
(* *****         Higgses         ***** *)
(*                                     *)
(* *********************************** *)

M$HiggsFields = {
(* Higgs: unphysical scalars  *)
  S[11] == {
    ClassName      -> Phi1,
    Unphysical     -> True,
    Indices        -> {Index[SU2D]},
    FlavorIndex    -> SU2D,
    SelfConjugate  -> False,
    QuantumNumbers -> {Y -> 1/2},
    Definitions    -> { Phi1[1] -> -I GP, Phi1[2] -> (vev + sinalf S + cosalf H  + I G0)/Sqrt[2]  }
  },

  S[12] == {
    ClassName      -> SH0,
    SelfConjugate  -> True,
    Unphysical     -> True,
    Definitions    -> { SH0 -> (sev + cosalf S - sinalf H )/Sqrt[2]  }
  },


(* Higgs: goldstone boson  *)
  S[21] == {
    ClassName       -> G0,
    SelfConjugate   -> True,
    Goldstone       -> Z,
    Mass            -> {MZ, 91.1876},
    Width           -> {WZ, 2.4952},
    PropagatorLabel -> "Go",
    PropagatorType  -> D,
    PropagatorArrow -> None,
    PDG             -> 250,
    ParticleName    -> "G0",
    FullName        -> "G0"
  },
  S[22] == {
    ClassName        -> GP,
    SelfConjugate    -> False,
    Goldstone        -> W,
    Mass             -> {MW, Internal},
    QuantumNumbers   -> {Q -> 1},
    Width            -> {WW, 2.085},
    PropagatorLabel  -> "GP",
    PropagatorType   -> D,
    PropagatorArrow  -> None,
    PDG              -> 251,
    ParticleName     -> "G+",
    AntiParticleName -> "G-",
    FullName         -> "GP"
  },

(* Higgs : physical states*)
  S[1] == {
    ClassName     -> H,
    SelfConjugate -> True,
    Mass -> {MH,  125.},
    Width -> {WH, 1},
    PDG -> {25},
    PropagatorType -> ScalarDash,
    PropagatorArrow -> None,
    PropagatorLabel  -> "H",
    ParticleName    -> "H",
    FullName        -> "H"
  },

  S[2] == {
    ClassName       -> S,
    SelfConjugate   -> True,
    Mass            -> {MS, 250.},
    Width           -> {WS, 0.407},
    PropagatorLabel -> "S",
    PropagatorType  -> D,
    PropagatorArrow -> None,
    ParticleName    -> "S",
    FullName        -> "S"
  }
};






